<?php

namespace Drupal\views_exposed_form_mobile\Hook;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\Render\Element;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Contains hook implementations for the Views exposed form mobile module.
 */
class ViewsExposedFormMobileHooks {

  use StringTranslationTrait;

  /**
   * Implements hook_help().
   */
  #[Hook('help')]
  public function help($route_name, RouteMatchInterface $route_match) {
    switch ($route_name) {
      case 'help.page.views_exposed_form_mobile':
        return $this->t("This module changes Views exposed filters to show a multi-page UI on mobile devices.");
    }
  }

  /**
   * Implements hook_form_FORM_ID_alter(): views_exposed_form.
   */
  #[Hook('form_views_exposed_form_alter')]
  public function formViewsExposedFormAlter(&$form, FormStateInterface $form_state, $form_id) {
    $display = $form_state->get('display');

    // Bail if the display extender is not enabled for the current display.
    if (empty($display['display_options']['display_extenders']['views_exposed_form_mobile']['views_exposed_form_mobile'])) {
      return;
    }

    $form['#attached']['library'][] = 'views_exposed_form_mobile/mobile-pages';

    $filters = [];

    foreach (Element::children($form) as $key) {
      // With Facets module enabled, the exposed form is built twice, the first
      // time with empty elements for the facets.
      if (!isset($form[$key]['#type'])) {
        continue;
      }
      if (in_array($form[$key]['#type'], ['actions', 'hidden'])) {
        continue;
      }

      // @todo Skip exposed sort.

      // Build up array of filters for the overview page.
      $filters[$key] = $form[$key]['#title'];

      // We need to act in #pre_render rather than #after_builder, as if BEF is
      // present and converts a filter to checkboxes,
      // preRenderCompositeFormElement() adds a 'fieldset' #theme_wrapper and
      // ours needs to go after it.
      $form[$key]['#pre_render'][] = function (array $element) {
        $element['#theme_wrappers'][] = 'views_exposed_form_mobile_filter_page';

        return $element;
      };
    }

    $form['actions']['#pre_render'][] = function (array $element) use ($filters) {
      $element['#theme_wrappers']['views_exposed_form_mobile_overview_page'] = [
        '#filters' => $filters,
      ];

      return $element;
    };

    // The link to open the overview page on mobile.
    $form['views_exposed_form_mobile_overview_link'] = [
      '#theme' => 'views_exposed_form_mobile_overview_open_button',
      '#title' => $this->t('Filters'),
    ];
  }

}
