<?php

namespace Drupal\views_exposed_form_mobile\Plugin\views\display_extender;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\views\Attribute\ViewsDisplayExtender;
use Drupal\views\Plugin\views\display_extender\DisplayExtenderPluginBase;

/**
 * Display extender plugin which marks a view as using mobile exposed form.
 */
#[ViewsDisplayExtender(
  id: 'views_exposed_form_mobile',
  title: new TranslatableMarkup('Views Exposed Form Mobile'),
  short_title: new TranslatableMarkup('Views Exposed Form Mobile'),
)]
class ViewsExposedFormMobile extends DisplayExtenderPluginBase {

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();

    $options['views_exposed_form_mobile'] = ['default' => FALSE];

    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    $section = $form_state->get('section');

    switch ($section) {
      case 'exposed_form':
        $form['views_exposed_form_mobile'] = [
          '#type' => 'checkbox',
          '#title' => $this->t("Show this exposed block as overlay pages on mobile"),
          '#description' => $this->t('When enabled, the exposed block for this display shows only a button on mobile, which opens overlays to set the exposed form values.'),
          '#default_value' => $this->options['views_exposed_form_mobile'],
        ];

        break;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitOptionsForm(&$form, FormStateInterface $form_state) {
    parent::submitOptionsForm($form, $form_state);

    if ($form_state->get('section') == 'exposed_form') {
      // Save options for this plugin.
      foreach ($this->defineOptions() as $option_name => $definition) {
        $this->options[$option_name] = $form_state->getValue($option_name);
      }
    }
  }

}
